@@ -1,205 +1,73 @@
 
-#' Package sources
+#' Install packages
 #'
-#' @section Standard packages:
-#'
-#' pak can install packages from various package sources. By default,
-#' a package name without the specification of its source, refers to a
-#' CRAN or Bioconductor package. pak calls these _standard_ packages.
-#' For example:
-#'
-#' ```r
-#' ## CRAN package
-#' pkg_install("glue")
-#' ## BioC package
-#' pkg_install("limma")
-#' ```
-#' When considering a standard package, the calling version of R is used
-#' to determine the available source and binary packages on CRAN and the
-#' Bioconductor repositories.
-#'
-#' The full specification of standard packages is simply
-#' ```
-#' [standard::]<package>
-#' ```
-#'
-#' If you know the exact source of the package, you can also write
-#' ```
-#' cran::<package>
-#' bioc::<package>
-#' ```
-#'
-#' @section GitHub packages:
-#'
-#' pak can install packages from GitHub repositories. Any package that
-#' is specified in the `user/repo` notation is taken to be a GitHub package.
-#' For example:
-#'
-#' ```r
-#' ## Package from GitHub
-#' pkg_install("r-lib/glue")
-#' ```
-#'
-#' The full specification of GitHub packages is
-#' ```
-#' [<package>=][github::]<username>/<repo>[/<subdir>]
-#'     [@<committish> | #<pull> | @[*]release]
-#'
-#' ```
-#'
-#' * `<package>` is the name of the package. If this is missing, the
-#'   name of the package must match the name of the repository.
-#' * `<username>`: GitHub user or organization name.
-#' * `<repo>`: repository name.
-#' * `<subdir>`: If the R package is in a subdirectory within the
-#'   repository.
-#' * `<commitish>`: A branch name, git tag or SHA hash, to specify the
-#'   branch, tag or commit to download or install.
-#' * `<pull>`: Pull request number, to install the branch that corresponds
-#'   to a pull request.
-#' * The `@*release` string can be used to install the latest release.
-#'
-#' @section Local package trees:
-#'
-#' pak can install packages from package trees. You can either use the
-#' [local_install()] function for this, or specify the `local::` package
-#' source. E.g. these are equivalent:
-#'
-#' ```r
-#' local_install("/path/to/my/package")
-#' pkg_install("local::/path/to/my/package")
-#' ```
-#'
-#' The `local::` form is handy if you want to mix it with other package
-#' specifications, e.g. to install a local package, and another standard
-#' package:
-#'
-#' ```r
-#' pkg_install(c("local://path/to/my/package", "testthat"))
-#' ```
-#'
-#' @section The `Remotes` field:
-#'
-#' You can mark any regular dependency defined in the `Depends`, `Imports`,
-#' `Suggests` or `Enhances` fields as being installed from a remote
-#' location by adding the remote location to `Remotes` in your
-#' `DESCRIPTION` file. This will cause pak to download and install them
-#' from the specified location, instead of CRAN.
-#'
-#' The remote dependencies specified in `Remotes` is a comma separated
-#' list of package sources:
-#'
-#' ```
-#' Remotes: <pkg-source-1>, <pkg-source-2>, [ ... ]
-#' ```
-#'
-#' Note that you will still need add the package to one of the regular
-#' dependency fields, i.e. `Imports`, `Suggests`, etc. Here is a concrete
-#' example that specifies the `r-lib/glue` package:
-#'
-#' ```
-#' Imports: glue
-#' Remotes: r-lib/glue,
-#'   r-lib/httr@v0.4,
-#'   klutometis/roxygen#142,
-#'   r-lib/testthat@c67018fa4970
-#' ```
-#'
-#' The CRAN and Bioconductor repositories do not support the `Remotes`
-#' field, so you need to remove this field, before submitting your package
-#' to either of them.
-#'
-#' @section The package dependency solver:
-#'
-#' pak contains a package dependency solver, that makes sure that the
-#' package source and version requirements of all packages are satisfied,
-#' before starting an installation. For CRAN and BioC packages this is
-#' usually automatic, because these repositories are generally in a
-#' consistent state. If packages depend on other other package sources,
-#' however, this is not the case.
-#'
-#' Here is an example of a conflict detected:
-#' ```
-#' > pak::pkg_install(c("r-lib/pkgcache@conflict", "r-lib/cli@message"))
-#' Error: Cannot install packages:
-#'   * Cannot install `r-lib/pkgcache@conflict`.
-#'     - Cannot install dependency r-lib/cli@main
-#'   * Cannot install `r-lib/cli@main`.
-#' - Conflicts r-lib/cli@message
-#' ```
-#'
-#' `r-lib/pkgcache@conflict` depends on the main branch of `r-lib/cli`,
-#' whereas, we explicitly requested the `message` branch. Since it cannot
-#' install both versions into a single library, pak quits.
-#'
-#' When pak considers a package for installation, and the package is given
-#' with its name only, (e.g. as a dependency of another package), then
-#' the package may have _any_ package source. This is necessary, because
-#' one R package library may contain only at most one version of a package
-#' with a given name.
-#'
-#' pak's behavior is best explained via an example.
-#' Assume that you are installing a local package (see below), e.g.
-#' `local::.`, and the local package depends on `pkgA` and `user/pkgB`,
-#' the latter being a package from GitHub (see below), and that `pkgA`
-#' also depends on `pkgB`. Now pak must install `pkgB` _and_ `user/pkgB`.
-#' In this case pak interprets `pkgB` as a package from any package source,
-#' instead of a standard package, so installing `user/pkgB` satisfies both
-#' requirements.
-#'
-#' Note that that `cran::pkgB` and `user/pkgB` requirements result a
-#' conflict that pak cannot resolve. This is because the first one _must_
-#' be a CRAN package, and the second one _must_ be a GitHub package, and
-#' two different packages with the same cannot be installed into an R
+#' Install one or more packages and their dependencies into a single
 #' package library.
 #'
-#' @name pak_package_sources
-#' @family package functions
-NULL
-
-#' Install a package
+#' @param pkg Package names or package references. E.g.
+#'   - `ggplot2`: package from CRAN, Bioconductor or a CRAN-like repository
+#'     in general,
+#'   - `tidyverse/ggplot2`: package from GitHub,
+#'   - `tidyverse/ggplot2@v3.4.0`: package from GitHub tag or branch,
+#'   - `https://examples.com/.../ggplot2_3.3.6.tar.gz`: package from URL,
+#'   - `.`: package in the current working directory.
 #'
-#' Install a package and its dependencies into a single package library.
-#'
-#' @param pkg Package names or remote package specifications to install.
-#'   See [pak package sources][pak_package_sources] for details.
+#'   See "[Package sources]" for more details.
 #' @param lib Package library to install the packages to. Note that _all_
-#'   dependent packages will the be installed here, even if they are
-#'   already installed in another library.
-#' @param upgrade When `FALSE`, the default, does the minimum amount of work
-#'   to give you the latest version of `pkg`. It will only upgrade packages if
-#'   `pkg`, or one of its dependencies, explicitly requires a higher version
-#'   than what you currently have.
+#'   dependent packages will be installed here, even if they are
+#'   already installed in another library. The only exceptions are base
+#'   and recommended packages installed in `.Library`. These are not
+#'   duplicated in `lib`, unless a newer version of a recommemded package
+#'   is needed.
+#' @param upgrade When `FALSE`, the default, pak does the minimum amount
+#'   of work to give you the latest version(s) of `pkg`. It will only upgrade
+#'   dependent packages if `pkg`, or one of their dependencies explicitly
+#'   require a higher version than what you currently have. It will also
+#'   prefer a binary package over to source package, even it the binary
+#'   package is older.
 #'
-#'   When `upgrade = TRUE`, will do ensure that you have the latest version of
-#'   `pkg` and all its dependencies.
+#'   When `upgrade = TRUE`, pak will ensure that you have the latest
+#'   version(s) of `pkg` and all their dependencies.
 #' @param ask Whether to ask for confirmation when installing a different
 #'   version of a package that is already installed. Installations that only
 #'   add new packages never require confirmation.
-#' @param dependencies Dependency types. See
-#'   [pkgdepends::as_pkg_dependencies()] for possible values. Note that
-#'   changing this argument from the default might result an installation
-#'   failure, e.g. if you set it to `FALSE`, packages might not build if
-#'   their dependencies are not already installed.
+#' @param dependencies What kinds of dependencies to install. Most commonly
+#'   one of the following values:
+#'   - `NA`: only required (hard) dependencies,
+#'   - `TRUE`: required dependencies plus optional and development
+#'     dependencies,
+#'   - `FALSE`: do not install any dependencies. (You might end up with a
+#'     non-working package, and/or the installation might fail.)
+#'   See [Package dependency types] for other possible values and more
+#'   information about package dependencies.
 #' @return (Invisibly) A data frame with information about the installed
 #'   package(s).
 #'
 #' @export
+#' @seealso [Get started with pak], [Package sources], [FAQ],
+#'   [The dependency solver].
 #' @family package functions
-#' @examples
-#' \dontrun{
+#' @section Examples:
+#' ```{asciicast pkg-install-dplyr}
 #' pkg_install("dplyr")
+#' ```
 #'
-#' # Upgrade dplyr and all its dependencies
+#' Upgrade dplyr and all its dependencies:
+#' ```{asciicast pkg-install-upgrade}
 #' pkg_install("dplyr", upgrade = TRUE)
+#' ````
 #'
-#' # Install the development version of dplyr
+#' Install the development version of dplyr:
+#' ```{asciicast pkg-install-gh}
 #' pkg_install("tidyverse/dplyr")
+#' ```
 #'
-#' # Switch back to the CRAN version. This will be fast because
-#' # pak will have cached the prior install.
+#' Switch back to the CRAN version. This will be fast because
+#' pak will have cached the prior install.
+#' ```{asciicast pkg-install-cran}
 #' pkg_install("dplyr")
-#' }
+#' ```
+
 pkg_install <- function(pkg, lib = .libPaths()[[1L]], upgrade = FALSE,
                         ask = interactive(), dependencies = NA) {
 
@@ -272,15 +140,16 @@ pkg_install_do_plan <- function(proposal, lib) {
 #'
 #' @param pkg Name of one or more installed packages to display status for.
 #' @param lib One or more library paths to lookup packages status in.
+#'   By default all libraries are used.
 #' @return Data frame with data about installations of `pkg`.
-#' Columns include: `library`, `package`, `title`, `version`.
+#'   \eval{pak:::include_docs("pkgdepends", "docs/lib-status-return.rds")}
 #'
 #' @export
 #' @family package functions
-#' @examples
-#' \dontrun{
+#' @section Examples:
+#' ```{asciicast pkg-status}
 #' pkg_status("MASS")
-#' }
+#' ```
 
 pkg_status <- function(pkg, lib = .libPaths()) {
   stopifnot(length(pkg == 1) && is.character(pkg))
@@ -293,13 +162,14 @@ pkg_status <- function(pkg, lib = .libPaths()) {
 
 pkg_status_internal <- function(pkg, lib = .libPaths()) {
   st <- lapply(lib, pkgdepends::lib_status, packages = pkg)
-  do.call(rbind, st)
+  do.call("rbind_expand", st)
 }
 
 #' Remove installed packages
 #'
 #' @param pkg A character vector of packages to remove.
-#' @param lib library to remove packages from
+#' @param lib library to remove packages from.
+#' @return Nothing.
 #' @export
 #' @family package functions
 
@@ -321,18 +191,24 @@ pkg_remove_internal <- function(pkg, lib) {
 
 #' Look up the dependencies of a package
 #'
-#' @param pkg Package name or remote package specification to resolve.
 #' @param upgrade Whether to use the most recent available package
 #'   versions.
-#' @param dependencies Dependency types. See
-#'   [pkgdepends::as_pkg_dependencies()] for possible values.
-#' @return A data frame.
+#' @inheritParams pkg_install
+#' @return A data frame with the dependency data, it includes `pkg`
+#'   as well. It has the following columns.
+#'   \eval{pak:::include_docs("pkgdepends", "docs/resolution-result.rds")}
 #'
 #' @family package functions
 #' @export
-#' @examplesIf FALSE
-#' pkg_deps("curl")
-#' pkg_deps("r-lib/fs")
+#' @section Examples:
+#' ```{asciicast pkg-deps}
+#' pkg_deps("dplyr")
+#' ```
+#'
+#' For a package on GitHub:
+#' ```{asciicast pkg-deps-gh}
+#' pkg_deps("r-lib/callr")
+#' ```
 
 pkg_deps <- function(pkg, upgrade = TRUE, dependencies = NA) {
   stopifnot(length(pkg == 1) && is.character(pkg))
@@ -367,18 +243,21 @@ pkg_deps_internal2 <- function(pkg, upgrade, dependencies) {
 
 #' Draw the dependency tree of a package
 #'
-#' @param pkg Package name or remote package specification to resolve.
 #' @param upgrade Whether to use the most recent available package
 #'   versions.
-#' @param dependencies Dependency types. See
-#'   [pkgdepends::as_pkg_dependencies()] for possible values.
+#' @inheritParams pkg_install
 #' @return The same data frame as [pkg_deps()], invisibly.
 #'
 #' @family package functions
 #' @export
-#' @examplesIf FALSE
+#' @section Examples:
+#' ```{asciicast pkg-deos-tree}
 #' pkg_deps_tree("dplyr")
+#' ```
+#'
+#' ```{asciicast pkg-deps-tree-2}
 #' pkg_deps_tree("r-lib/usethis")
+#' ```
 
 pkg_deps_tree <- function(pkg, upgrade = TRUE, dependencies = NA) {
   stopifnot(length(pkg == 1) && is.character(pkg))
@@ -409,27 +288,41 @@ pkg_list <- function(lib = .libPaths()[1]) {
   lib_status(lib)
 }
 
-#' Download a package and potentially its dependencies as well
+#' Download a package and its dependencies
+#'
+#' TODO: explain result
 #'
-#' @param pkg Package names or remote package specifications to download.
 #' @param dest_dir Destination directory for the packages. If it does not
 #'   exist, then it will be created.
-#' @param dependencies Dependency types, to download the (recursive)
-#'   dependencies of `pkg` as well. See [pkgdepends::as_pkg_dependencies()]
-#'   for possible values.
 #' @param platforms Types of binary or source packages to download. The
 #'   default is the value of [pkgdepends::default_platforms()].
 #' @param r_versions R version(s) to download packages for. (This does not
 #'   matter for source packages, but it does for binaries.) It defaults to
 #'   the current R version.
+#' @inheritParams pkg_install
 #' @return Data frame with information about the downloaded
-#'   packages, invisibly.
+#'   packages, invisibly. Columns:
+#'   \eval{pak:::include_docs("pkgdepends", "docs/download-result.rds")}
 #'
 #' @export
 #' @family package functions
-#' @examplesIf FALSE
-#' pkg_download("forcats")
+#' @section Examples:
+#'
+#' ```{asciicast pkg-download}
+#' dl <- pkg_download("forcats")
+#' ```
+#'
+#' ```{asciicast pkg-download-2}
+#' dl
+#' ```
+#'
+#' ```{asciicast pkg-download-3}
+#' dl$fulltarget
+#' ```
+#'
+#' ```{asciicast pkg-download-4}
 #' pkg_download("r-lib/pak", platforms = "source")
+#' ```
 
 pkg_download <- function(pkg, dest_dir = ".", dependencies = FALSE,
                          platforms = NULL, r_versions = NULL) {
